@@ -50,7 +50,7 @@ def add_need(
     is_external=False,
     external_url=None,
     external_css="external_link",
-    **kwargs
+    **kwargs,
 ):
     """
     Creates a new need and returns its node.
@@ -178,11 +178,10 @@ def add_need(
 
     # Handle status
     # Check if status is in needs_statuses. If not raise an error.
-    if env.app.config.needs_statuses:
-        if status not in [stat["name"] for stat in env.app.config.needs_statuses]:
-            raise NeedsStatusNotAllowed(
-                "Status {0} of need id {1} is not allowed " "by config value 'needs_statuses'.".format(status, need_id)
-            )
+    if env.app.config.needs_statuses and status not in [stat["name"] for stat in env.app.config.needs_statuses]:
+        raise NeedsStatusNotAllowed(
+            f"Status {status} of need id {need_id} is not allowed " "by config value 'needs_statuses'."
+        )
 
     if tags is None:
         tags = []
@@ -194,9 +193,7 @@ def add_need(
         new_tags = []  # Shall contain only valid tags
         for i in range(len(tags)):
             if len(tags[i]) == 0 or tags[i].isspace():
-                logger.warning(
-                    "Scruffy tag definition found in need {}. " "Defined tag contains spaces only.".format(need_id)
-                )
+                logger.warning(f"Scruffy tag definition found in need {need_id}. " "Defined tag contains spaces only.")
             else:
                 new_tags.append(tags[i])
 
@@ -206,7 +203,7 @@ def add_need(
             for tag in tags:
                 if tag not in [tag["name"] for tag in env.app.config.needs_tags]:
                     raise NeedsTagNotAllowed(
-                        "Tag {0} of need id {1} is not allowed " "by config value 'needs_tags'.".format(tag, need_id)
+                        f"Tag {tag} of need id {need_id} is not allowed " "by config value 'needs_tags'."
                     )
         # This may have cut also dynamic function strings, as they can contain , as well.
         # So let put them together again
@@ -220,11 +217,11 @@ def add_need(
     if not hasattr(env, "needs_all_needs"):
         env.needs_all_needs = {}
 
-    if need_id in env.needs_all_needs.keys():
+    if need_id in env.needs_all_needs:
         if id:
             raise NeedsDuplicatedId(
-                "A need with ID {} already exists! "
-                "This is not allowed. Document {}[{}] Title: {}.".format(need_id, docname, lineno, title)
+                f"A need with ID {need_id} already exists! "
+                f"This is not allowed. Document {docname}[{lineno}] Title: {title}."
             )
         else:  # this is a generated ID
             raise NeedsDuplicatedId(
@@ -300,11 +297,11 @@ def add_need(
 
     for link_type in env.config.needs_extra_links:
         # Check, if specific link-type got some arguments during method call
-        if link_type["option"] not in list(kwargs.keys()) and link_type["option"] not in needs_global_options.keys():
+        if link_type["option"] not in kwargs and link_type["option"] not in needs_global_options:
             # if not we set no links, but entry in needS_info must be there
             links = []
-        elif link_type["option"] in needs_global_options.keys() and (
-            link_type["option"] not in list(kwargs.keys()) or len(str(kwargs[link_type["option"]])) == 0
+        elif link_type["option"] in needs_global_options and (
+            link_type["option"] not in kwargs or len(str(kwargs[link_type["option"]])) == 0
         ):
             # If it is in global option, value got already set during prior handling of them
             links_string = needs_info[link_type["option"]]
@@ -317,7 +314,7 @@ def add_need(
         needs_info[link_type["option"]] = links
         needs_info["{}_back".format(link_type["option"])] = []
 
-        if "copy" not in link_type.keys():
+        if "copy" not in link_type:
             link_type["copy"] = False
 
         if link_type["copy"] and link_type["option"] != "links":
@@ -362,7 +359,7 @@ def add_need(
     # Title and meta data information gets added alter during event handling via process_need_nodes()
     # We just add a basic need node and render the rst-based content, because this can not be done later.
     # style_classes = ['need', type_name, 'need-{}'.format(type_name.lower())]  # Used < 0.4.4
-    style_classes = ["need", "need-{}".format(need_type.lower())]
+    style_classes = ["need", f"need-{need_type.lower()}"]
     if style:
         style_classes.append(style)
 
@@ -401,10 +398,10 @@ def del_need(app, id):
     :param app: Sphinx application object.
     :param id: Sphinx need id.
     """
-    if id in app.env.needs_all_needs.keys():
+    if id in app.env.needs_all_needs:
         del app.env.needs_all_needs[id]
     else:
-        logger.warning("Given need id {} not exists!".format(id))
+        logger.warning(f"Given need id {id} not exists!")
 
 
 def add_external_need(
@@ -418,7 +415,7 @@ def add_external_need(
     status=None,
     tags=None,
     links_string=None,
-    **kwargs
+    **kwargs,
 ):
     """
     Adds an external need from an external source.
@@ -466,14 +463,14 @@ def _prepare_template(app, needs_info, template_key):
         template_folder = os.path.join(app.confdir, template_folder)
 
     if not os.path.isdir(template_folder):
-        raise NeedsTemplateException("Template folder does not exist: {}".format(template_folder))
+        raise NeedsTemplateException(f"Template folder does not exist: {template_folder}")
 
     template_file_name = needs_info[template_key] + ".need"
     template_path = os.path.join(template_folder, template_file_name)
     if not os.path.isfile(template_path):
-        raise NeedsTemplateException("Template does not exist: {}".format(template_path))
+        raise NeedsTemplateException(f"Template does not exist: {template_path}")
 
-    with open(template_path, "r") as template_file:
+    with open(template_path) as template_file:
         template_content = "".join(template_file.readlines())
     template_obj = Template(template_content)
     new_content = template_obj.render(**needs_info)
@@ -503,9 +500,7 @@ def _read_in_links(links_string: Union[str, List[str]]):
             link_list = links_string
         for link in link_list:
             if link.isspace():
-                logger.warning(
-                    "Grubby link definition found in need {}. " "Defined link contains spaces only.".format(id)
-                )
+                logger.warning(f"Grubby link definition found in need {id}. " "Defined link contains spaces only.")
             else:
                 links.append(link.strip())
 
@@ -537,10 +532,10 @@ def make_hashed_id(app, need_type, full_title, content, id_length=None):
             type_prefix = ntype["prefix"]
             break
     if type_prefix is None:
-        raise NeedsInvalidException("Given need_type {} is unknown. File {}".format(need_type, app.env.docname))
+        raise NeedsInvalidException(f"Given need_type {need_type} is unknown. File {app.env.docname}")
 
     hashable_content = full_title or "\n".join(content)
-    return "%s%s" % (type_prefix, hashlib.sha1(hashable_content.encode("UTF-8")).hexdigest().upper()[:id_length])
+    return "{}{}".format(type_prefix, hashlib.sha1(hashable_content.encode("UTF-8")).hexdigest().upper()[:id_length])
 
 
 def _fix_list_dyn_func(list):
@@ -609,7 +604,7 @@ def _merge_global_options(app, needs_info, global_options):
     for key, value in global_options.items():
 
         # If key already exists in needs_info, this global_option got overwritten manually in current need
-        if key in needs_info.keys() and needs_info[key]:
+        if key in needs_info and needs_info[key]:
             continue
 
         if isinstance(value, tuple):
@@ -622,7 +617,7 @@ def _merge_global_options(app, needs_info, global_options):
 
         for single_value in values:
             if len(single_value) < 2 or len(single_value) > 3:
-                raise NeedsInvalidException("global option tuple has wrong amount of parameters: {}".format(key))
+                raise NeedsInvalidException(f"global option tuple has wrong amount of parameters: {key}")
             if filter_single_need(app, needs_info, single_value[1]):
                 # Set value, if filter has matched
                 needs_info[key] = single_value[0]
