@@ -37,7 +37,7 @@ class NeedextendDirective(Directive):
             env.needs_all_needs = {}
 
         id = env.new_serialno("needextend")
-        targetid = "needextend-{docname}-{id}".format(docname=env.docname, id=id)
+        targetid = f"needextend-{env.docname}-{id}"
         targetnode = nodes.target("", "", ids=[targetid])
 
         extend_filter = self.arguments[0] if self.arguments else None
@@ -74,7 +74,7 @@ def process_needextend(app, doctree, fromdocname):
         )  # back-links (incoming)
         link_names = [x["option"] for x in app.config.needs_extra_links]
 
-        for extend_name, current_needextend in env.need_all_needextend.items():
+        for current_needextend in env.need_all_needextend.values():
 
             # Check if filter is just a need-id.
             # In this case create the needed filter string
