@@ -3,7 +3,9 @@ import re
 from docutils import nodes
 from docutils.parsers.rst import directives
 
+from sphinxcontrib.needs.api.exceptions import NeedsInvalidException
 from sphinxcontrib.needs.directives.utils import (
+    get_option_list,
     get_title,
     no_needs_found_paragraph,
     used_filter_paragraph,
@@ -28,10 +30,12 @@ class NeedtableDirective(FilterBase):
         "show_filters": directives.flag,
         "show_parts": directives.flag,
         "columns": directives.unchanged_required,
+        "colwidths": directives.unchanged_required,
         "style": directives.unchanged_required,
         "style_row": directives.unchanged_required,
         "style_col": directives.unchanged_required,
         "sort": directives.unchanged_required,
+        "class": directives.unchanged_required,
     }
 
     # Update the options_spec with values defined in the FilterBase class
@@ -58,6 +62,18 @@ class NeedtableDirective(FilterBase):
 
         columns = [get_title(col) for col in columns]
 
+        colwidths = str(self.options.get("colwidths", ""))
+        colwidths_list = []
+        if colwidths:
+            colwidths_list = [int(width.strip()) for width in re.split(";|,", colwidths)]
+            if len(columns) != len(colwidths_list):
+                raise NeedsInvalidException(
+                    f"Amount of elements in colwidths and columns do not match: "
+                    f"colwidths: {len(colwidths_list)} and columns: {len(columns)}"
+                )
+
+        classes = get_option_list(self.options, "class")
+
         style = self.options.get("style", "").upper()
         style_row = self.options.get("style_row", "")
         style_col = self.options.get("style_col", "")
@@ -74,15 +90,17 @@ class NeedtableDirective(FilterBase):
             "lineno": self.lineno,
             "target_node": targetnode,
             "caption": title,
+            "classes": classes,
             "columns": columns,
+            "colwidths": colwidths_list,
             "style": style,
             "style_row": style_row,
             "style_col": style_col,
             "sort": sort,
             # As the following options are flags, the content is None, if set.
             # If not set, the options.get() method returns False
-            "show_filters": True if self.options.get("show_filters", False) is None else False,
-            "show_parts": True if self.options.get("show_parts", False) is None else False,
+            "show_filters": self.options.get("show_filters", False) is None,
+            "show_parts": self.options.get("show_parts", False) is None,
             "env": env,
         }
         env.need_all_needtables[targetid].update(self.collect_filter_attributes())
@@ -142,7 +160,7 @@ def process_needtables(app, doctree, fromdocname):
             style = current_needtable["style"].upper()
 
         # Prepare table
-        classes = ["NEEDS_{style}".format(style=style)]
+        classes = [f"NEEDS_{style}"] + current_needtable["classes"]
 
         # Only add the theme specific "do not touch this table" class, if we use a style which
         # care about table layout and styling. The normal "TABLE" style is using the Sphinx default table
@@ -154,15 +172,19 @@ def process_needtables(app, doctree, fromdocname):
         tgroup = nodes.tgroup()
 
         # Define Table column width
-        # ToDo: Find a way to chosen to perfect width automatically.
-        for option, title in current_needtable["columns"]:
-            if option == "TITLE":
+        colwidths = current_needtable["colwidths"]
+        for index, value in enumerate(current_needtable["columns"]):
+            option, _title = value
+
+            if colwidths:  # Get values from given colwidths option
+                tgroup += nodes.colspec(colwidth=colwidths[index])
+            elif option == "TITLE":  # if nothing in colwidths...
                 tgroup += nodes.colspec(colwidth=15)
             else:
                 tgroup += nodes.colspec(colwidth=5)
 
         node_columns = []
-        for option, title in current_needtable["columns"]:
+        for _option, title in current_needtable["columns"]:
             header_name = title
             node_columns.append(nodes.entry("", nodes.paragraph("", header_name)))
 
@@ -174,7 +196,10 @@ def process_needtables(app, doctree, fromdocname):
         all_needs = list(all_needs.values())
 
         # Perform filtering of needs
-        found_needs = process_filters(app, all_needs, current_needtable)
+        try:
+            found_needs = process_filters(app, all_needs, current_needtable)
+        except Exception as e:
+            raise e
 
         def get_sorter(key):
             """
@@ -213,20 +238,16 @@ def process_needtables(app, doctree, fromdocname):
                 prefix = app.config.needs_part_prefix
                 temp_need["title"] = temp_need["content"]
 
-            for option, title in current_needtable["columns"]:
+            for option, _title in current_needtable["columns"]:
                 if option == "ID":
                     row += row_col_maker(
                         app, fromdocname, env.needs_all_needs, temp_need, "id", make_ref=True, prefix=prefix
                     )
                 elif option == "TITLE":
                     row += row_col_maker(app, fromdocname, env.needs_all_needs, temp_need, "title", prefix=prefix)
-                elif option in link_type_list.keys():
+                elif option in link_type_list:
                     link_type = link_type_list[option]
-                    if (
-                        option == "INCOMING"
-                        or option == link_type["option"].upper() + "_BACK"
-                        or option == link_type["incoming"].upper()
-                    ):
+                    if option in ["INCOMING", link_type["option"].upper() + "_BACK", link_type["incoming"].upper()]:
                         row += row_col_maker(
                             app,
                             fromdocname,
@@ -256,7 +277,7 @@ def process_needtables(app, doctree, fromdocname):
 
                     row = nodes.row(classes=["need_part"])
 
-                    for option, title in current_needtable["columns"]:
+                    for option, _title in current_needtable["columns"]:
                         if option == "ID":
                             row += row_col_maker(
                                 app,
@@ -276,10 +297,13 @@ def process_needtables(app, doctree, fromdocname):
                                 "content",
                                 prefix=app.config.needs_part_prefix,
                             )
-                        elif option in link_type_list.keys() and (
-                            option == "INCOMING"
-                            or option == link_type_list[option]["option"].upper() + "_BACK"
-                            or option == link_type_list[option]["incoming"].upper()
+                        elif option in link_type_list and (
+                            option
+                            in [
+                                "INCOMING",
+                                link_type_list[option]["option"].upper() + "_BACK",
+                                link_type_list[option]["incoming"].upper(),
+                            ]
                         ):
                             row += row_col_maker(
                                 app,
@@ -306,4 +330,11 @@ def process_needtables(app, doctree, fromdocname):
             title = nodes.title(title_text, "", nodes.Text(title_text))
             content.insert(0, title)
 
-        node.replace_self(content)
+        # Put the table in a div-wrapper, so that we can control overflow / scroll layout
+        if style == "TABLE":
+            table_wrapper = nodes.container(classes=["needstable_wrapper"])
+            table_wrapper.insert(0, content)
+            node.replace_self(table_wrapper)
+
+        else:
+            node.replace_self(content)
