@@ -79,7 +79,7 @@ def process_filters(app, all_needs, current_needlist, include_external=True):
         try:
             all_needs = sorted(all_needs, key=lambda node: node[sort_key] or "")
         except KeyError as e:
-            log.warning("Sorting parameter {0} not valid: Error: {1}".format(sort_key, e))
+            log.warning(f"Sorting parameter {sort_key} not valid: Error: {e}")
 
     # check if include external needs
     checked_all_needs = []
@@ -121,11 +121,12 @@ def process_filters(app, all_needs, current_needlist, include_external=True):
         if bool(current_needlist["status"] or current_needlist["tags"] or current_needlist["types"]):
             for need_info in all_needs_incl_parts:
                 status_filter_passed = False
-                if not current_needlist["status"]:
-                    # Filtering for status was not requested
-                    status_filter_passed = True
-                elif need_info["status"] and need_info["status"] in current_needlist["status"]:
-                    # Match was found
+                if (
+                    not current_needlist["status"]
+                    or need_info["status"]
+                    and need_info["status"] in current_needlist["status"]
+                ):
+                    # Filtering for status was not requested or match was found
                     status_filter_passed = True
 
                 tags_filter_passed = False
@@ -155,10 +156,13 @@ def process_filters(app, all_needs, current_needlist, include_external=True):
             found_needs = filter_needs(app, all_needs_incl_parts, current_needlist["filter"])
     else:
         # Provides only a copy of needs to avoid data manipulations.
-        context = {
-            "needs": copy.deepcopy(all_needs_incl_parts),
-            "results": [],
-        }
+        try:
+            context = {
+                "needs": copy.deepcopy(all_needs_incl_parts),
+                "results": [],
+            }
+        except Exception as e:
+            raise e
 
         if filter_code:  # code from content
             exec(filter_code, context)
@@ -262,7 +266,7 @@ def filter_needs(app, needs, filter_string="", current_need=None):
             ):
                 found_needs.append(filter_need)
         except Exception as e:
-            log.warning("Filter {0} not valid: Error: {1}".format(filter_string, e))
+            log.warning(f"Filter {filter_string} not valid: Error: {e}")
 
     return found_needs
 
@@ -300,5 +304,5 @@ def filter_single_need(app, need, filter_string="", needs=None, current_need=Non
         else:
             result = bool(eval(filter_string, filter_context))
     except Exception as e:
-        raise NeedsInvalidFilter("Filter {0} not valid: Error: {1}".format(filter_string, e))
+        raise NeedsInvalidFilter(f"Filter {filter_string} not valid: Error: {e}")
     return result
