@@ -3,6 +3,7 @@ from sphinxcontrib.needs.functions.common import (
     calc_sum,
     check_linked_values,
     copy,
+    echo,
     links_from_content,
     test,
 )
@@ -14,4 +15,4 @@ from sphinxcontrib.needs.functions.functions import (
     resolve_dynamic_values,
 )
 
-needs_common_functions = [test, copy, check_linked_values, calc_sum, links_from_content]
+needs_common_functions = [test, echo, copy, check_linked_values, calc_sum, links_from_content]
