@@ -5,6 +5,7 @@ Based on https://github.com/useblocks/sphinxcontrib-needs/issues/102
 """
 import os
 import re
+from contextlib import suppress
 from urllib.parse import urlparse
 
 import requests
@@ -13,9 +14,10 @@ from docutils.frontend import OptionParser
 from docutils.parsers.rst import Parser, languages
 from docutils.parsers.rst.states import Inliner, Struct
 from docutils.utils import new_document
+from jinja2 import BaseLoader, Environment
 from sphinx.application import Sphinx
 
-from sphinxcontrib.needs.utils import INTERNALS
+from sphinxcontrib.needs.utils import INTERNALS, logger
 
 
 def create_need(need_id, app: Sphinx, layout=None, style=None, docname=None):
@@ -35,7 +37,7 @@ def create_need(need_id, app: Sphinx, layout=None, style=None, docname=None):
     needs = env.needs_all_needs
 
     if need_id not in needs.keys():
-        raise SphinxNeedLayoutException("Given need id {} does not exist.".format(need_id))
+        raise SphinxNeedLayoutException(f"Given need id {need_id} does not exist.")
     need_data = needs[need_id]
 
     node_container = nodes.container()
@@ -86,7 +88,7 @@ def build_need(layout, node, app, style=None, fromdocname=None):
     """
     Builds a need based on a given layout for a given need-node.
 
-    The created table must have ethe following docutils structure::
+    The created table must have the following docutils structure::
 
         - table
         -- tgroup
@@ -246,6 +248,21 @@ class LayoutHandler:
             "collapse_button": self.collapse_button,
         }
 
+        # Prepare string_links dict, so that regex and templates get not recompiled too often.
+        #
+        # Do not set needs_string_links here and update it.
+        # This would lead to deepcopy()-errors, as needs_string_links gets some "pickled" and jinja Environment is
+        # too complex for this.
+        self.string_links = {}
+        for link_name, link_conf in app.config.needs_string_links.items():
+            self.string_links[link_name] = {
+                "url_template": Environment(loader=BaseLoader).from_string(link_conf["link_url"]),
+                "name_template": Environment(loader=BaseLoader).from_string(link_conf["link_name"]),
+                "regex_compiled": re.compile(link_conf["regex"]),
+                "options": link_conf["options"],
+                "name": link_name,
+            }
+
     def get_need_table(self):
         if self.layout["grid"] not in self.grids.keys():
             raise SphinxNeedLayoutException(
@@ -271,7 +288,7 @@ class LayoutHandler:
         if len(lines) == 0:
             return []
 
-        lines_container = nodes.line_block(classes=["needs_{}".format(section)])
+        lines_container = nodes.line_block(classes=[f"needs_{section}"])
 
         for line in lines:
             # line_block_node = nodes.line_block()
@@ -383,7 +400,7 @@ class LayoutHandler:
                             node_line += result
                     else:
                         raise SphinxNeedLayoutException(
-                            "Error during layout line parsing. This looks strange: {}".format(line_element)
+                            f"Error during layout line parsing. This looks strange: {line_element}"
                         )
 
                 return_nodes.append(node_line)
@@ -396,7 +413,7 @@ class LayoutHandler:
                 raise SphinxNeedLayoutException(item)
             # To escape { we need to use 2 of them.
             # So {{ becomes {{{{
-            replace_string = "{{{{{}}}}}".format(item)
+            replace_string = f"{{{{{item}}}}}"
             data = data.replace(replace_string, self.need[item])
         return data
 
@@ -432,9 +449,47 @@ class LayoutHandler:
         if isinstance(data, str):
             if len(data) == 0 and not show_empty:
                 return []
-            data_node = nodes.inline(classes=["needs_data"])
-            data_node.append(nodes.Text(data, data))
+            # data_node = nodes.inline(classes=["needs_data"])
+            # data_node.append(nodes.Text(data, data))
+            # data_container.append(data_node)
+
+            matching_link_confs = []
+            for link_conf in self.string_links.values():
+                if name in link_conf["options"]:
+                    matching_link_confs.append(link_conf)
+
+            string_link_error = False
+            if matching_link_confs:
+                try:
+                    link_name = None
+                    link_url = None
+                    for link_conf in matching_link_confs:
+                        match = link_conf["regex_compiled"].search(data)
+                        if match:
+                            render_content = match.groupdict()
+                            link_url = link_conf["url_template"].render(**render_content)
+                            link_name = link_conf["name_template"].render(**render_content)
+                            break  # We only handle the first matching string_link
+                    data_node = nodes.inline(classes=["needs_data"])
+                    if link_name:
+                        data_node.append(nodes.reference(link_name, link_name, refuri=link_url))
+                    else:
+                        # if no string_link match was made, we handle it as normal string value
+                        data_node.append(nodes.Text(data, data))
+
+                except Exception as e:
+                    logger.warning(
+                        f'Problems dealing with string 2 link transformation for value "{data}" of '
+                        f'option "{name}". Error: {e}'
+                    )
+                    string_link_error = True  # Create normal text output
+            elif not matching_link_confs or string_link_error:
+                # Normal text handling
+                data_node = nodes.inline(classes=["needs_data"])
+                data_node.append(nodes.Text(data, data))
+
             data_container.append(data_node)
+
         elif isinstance(data, list):
             if len(data) == 0 and not show_empty:
                 return []
@@ -530,7 +585,7 @@ class LayoutHandler:
                 continue
 
             data_line = nodes.line()
-            label = prefix + "{}:".format(data) + postfix + " "
+            label = prefix + f"{data}:" + postfix + " "
             result = self.meta(data, label, show_empty)
             if not (show_empty or result):
                 continue
@@ -554,7 +609,7 @@ class LayoutHandler:
         """
         data_container = nodes.inline(classes=[name])
         if name not in [x["option"] for x in self.app.config.needs_extra_links]:
-            raise SphinxNeedLayoutException("Invalid link name {} for link-type".format(name))
+            raise SphinxNeedLayoutException(f"Invalid link name {name} for link-type")
 
         # if incoming:
         #     link_name = self.app.config.needs_extra_links[name]['incoming']
@@ -565,9 +620,9 @@ class LayoutHandler:
         from sphinxcontrib.needs.roles.need_outgoing import NeedOutgoing
 
         if incoming:
-            node_links = NeedIncoming(reftarget=self.need["id"], link_type="{}_back".format(name))
+            node_links = NeedIncoming(reftarget=self.need["id"], link_type=f"{name}_back")
         else:
-            node_links = NeedOutgoing(reftarget=self.need["id"], link_type="{}".format(name))
+            node_links = NeedOutgoing(reftarget=self.need["id"], link_type=f"{name}")
         node_links.append(nodes.inline(self.need["id"], self.need["id"]))
         data_container.append(node_links)
         return data_container
@@ -660,7 +715,7 @@ class LayoutHandler:
             url = os.path.join(
                 needs_location,
                 "images",
-                "feather_{}".format(builder_extension),
+                f"feather_{builder_extension}",
                 "{}.{}".format(url.split(":")[1], builder_extension),
             )
 
@@ -695,10 +750,8 @@ class LayoutHandler:
 
             # Download only, if file not downloaded yet
             if not os.path.exists(file_path):
-                try:
+                with suppress(FileExistsError):
                     os.mkdir(path)
-                except FileExistsError:
-                    pass
                 response = requests.get(url)
                 if response.status_code == 200:
                     with open(file_path, "wb") as f:
@@ -813,7 +866,8 @@ class LayoutHandler:
 
         if (not self.need["collapse"]) or (self.need["collapse"] is None and not initial):
             status = "show"
-        elif (self.need["collapse"]) or (not self.need["collapse"] and initial):
+
+        if (self.need["collapse"]) or (not self.need["collapse"] and initial):
             status = "hide"
 
         target_strings = target.split(",")
