@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 from docutils import nodes
 from docutils.parsers.rst import directives
 from sphinx.application import Sphinx
@@ -95,7 +93,7 @@ from sphinxcontrib.needs.services.manager import ServiceManager
 from sphinxcontrib.needs.utils import INTERNALS, NEEDS_FUNCTIONS
 from sphinxcontrib.needs.warnings import process_warnings
 
-VERSION = "0.7.3"
+VERSION = "0.7.4"
 NEEDS_FUNCTIONS.clear()
 
 
@@ -111,17 +109,20 @@ class TagsDummy:
 
 def setup(app):
     log = get_logger(__name__)
-    log.debug("Starting setup of sphinx-Needs")
+    log.debug("Starting setup of Sphinx-Needs")
+    log.debug("Load Sphinx-Data-Viewer for Sphinx-Needs")
+    app.setup_extension("sphinx_data_viewer")
+
     app.add_builder(NeedsBuilder)
     app.add_config_value(
         "needs_types",
         [
-            dict(directive="req", title="Requirement", prefix="R_", color="#BFD8D2", style="node"),
-            dict(directive="spec", title="Specification", prefix="S_", color="#FEDCD2", style="node"),
-            dict(directive="impl", title="Implementation", prefix="I_", color="#DF744A", style="node"),
-            dict(directive="test", title="Test Case", prefix="T_", color="#DCB239", style="node"),
+            {"directive": "req", "title": "Requirement", "prefix": "R_", "color": "#BFD8D2", "style": "node"},
+            {"directive": "spec", "title": "Specification", "prefix": "S_", "color": "#FEDCD2", "style": "node"},
+            {"directive": "impl", "title": "Implementation", "prefix": "I_", "color": "#DF744A", "style": "node"},
+            {"directive": "test", "title": "Test Case", "prefix": "T_", "color": "#DCB239", "style": "node"},
             # Kept for backwards compatibility
-            dict(directive="need", title="Need", prefix="N_", color="#9856a5", style="node"),
+            {"directive": "need", "title": "Need", "prefix": "N_", "color": "#9856a5", "style": "node"},
         ],
         "html",
     )
@@ -135,7 +136,7 @@ def setup(app):
     app.add_config_value("needs_id_required", False, "html", types=[bool])
     app.add_config_value(
         "needs_id_regex",
-        "^[A-Z0-9_]{{{id_length},}}".format(id_length=app.config.needs_id_length),
+        f"^[A-Z0-9_]{{{app.config.needs_id_length},}}",
         "html",
     )
     app.add_config_value("needs_show_link_type", False, "html", types=[bool])
@@ -216,6 +217,8 @@ def setup(app):
     # Additional classes to set for needs and needtable.
     app.add_config_value("needs_table_classes", NEEDS_TABLES_CLASSES, "html", types=[list])
 
+    app.add_config_value("needs_string_links", {}, "html", types=[dict])
+
     # Define nodes
     app.add_node(Need, html=(html_visit, html_depart), latex=(latex_visit, latex_depart))
     app.add_node(
@@ -453,12 +456,11 @@ def prepare_env(app, env, _docname):
 
     # Register user defined services
     for name, service in app.config.needs_services.items():
-        if name not in app.needs_services.services.keys():
+        if name not in app.needs_services.services and "class" in service and "class_init" in service:
             # We found a not yet registered service
             # But only register, if service-config contains class and class_init.
             # Otherwise the service may get registered later by an external sphinx-needs extension
-            if "class" in service and "class_init" in service:
-                app.needs_services.register(name, service["class"], **service["class_init"])
+            app.needs_services.register(name, service["class"], **service["class_init"])
 
     needs_functions = app.config.needs_functions
 
@@ -550,7 +552,7 @@ def check_configuration(_app: Sphinx, config: Config):
         # Check if external filter values is really a string
         if not isinstance(value, str):
             raise NeedsConfigException(
-                "External filter value: {0} from needs_filter_data {1} is not a string.".format(value, external_filter)
+                f"External filter value: {value} from needs_filter_data {external_filter} is not a string."
             )
         # Check if needs external filter and extra option are using the same name
         if extern_filter in extra_options:
