@@ -1,6 +1,7 @@
 import os
 import textwrap
 import time
+from contextlib import suppress
 from urllib.parse import urlparse
 
 import requests
@@ -48,20 +49,13 @@ class GithubService(BaseService):
             "commit": {"url": "search/commits", "query": "", "need_type": "commit"},
         }
 
-        try:
+        with suppress(NeedsApiConfigException):
+            # Issue already exists, so we are fine
             add_need_type(self.app, "issue", "Issue", "IS_", "#cccccc", "card")
-        except NeedsApiConfigException:
-            pass  # Issue already exists, so we are fine
-
-        try:
+            # PR already exists, so we are fine
             add_need_type(self.app, "pr", "PullRequest", "PR_", "#aaaaaa", "card")
-        except NeedsApiConfigException:
-            pass  # PR already exists, so we are fine
-
-        try:
+            # Commit already exists, so we are fine
             add_need_type(self.app, "commit", "Commit", "C_", "#888888", "card")
-        except NeedsApiConfigException:
-            pass  # Commit already exists, so we are fine
 
         if "gh_type" in kwargs:
             self.gh_type = kwargs["gh_type"]
@@ -105,7 +99,7 @@ class GithubService(BaseService):
             query = "{} {}".format(query, self.gh_type_config[self.gh_type]["query"])
             params = {"q": query, "per_page": options.get("max_amount", self.max_amount)}
 
-        self.log.info("Service {} requesting data for query: {}".format(self.name, query))
+        self.log.info(f"Service {self.name} requesting data for query: {query}")
 
         if self.username:
             auth = (self.username, self.token)
@@ -149,7 +143,7 @@ class GithubService(BaseService):
     def request(self, options=None):
         if options is None:
             options = {}
-        self.log.debug("Requesting data for service {}".format(self.name))
+        self.log.debug(f"Requesting data for service {self.name}")
 
         if "query" not in options and "specific" not in options:
             raise NeedGithubServiceException('"query" or "specific" missing as option for github service.')
@@ -163,8 +157,8 @@ class GithubService(BaseService):
             specific = True
 
         response = self._send(query, options, specific=specific)
-        if "items" not in response.keys():
-            if "errors" in response.keys():
+        if "items" not in response:
+            if "errors" in response:
                 raise NeedGithubServiceException(
                     "GitHub service query error: {}\n" "Used query: {}".format(response["errors"][0]["message"], query)
                 )
@@ -276,10 +270,8 @@ class GithubService(BaseService):
         if self.download_avatars:
             # Download only, if file not downloaded yet
             if not os.path.exists(avatar_file_path):
-                try:
+                with suppress(FileExistsError):
                     os.mkdir(path)
-                except FileExistsError:
-                    pass
                 if self.username and self.token:
                     auth = (self.username, self.token)
                 else:
